@@ -1,8 +1,8 @@
 
 /*
-  $Id: iface.c,v 1.5 2001/12/04 09:49:16 ldv Exp $
+  $Id: iface.c,v 1.8 2002/05/21 12:51:50 ldv Exp $
 
-  Copyright (C) 2001  Dmitry V. Levin <ldv@fandra.org>
+  Copyright (C) 2001,2002  Dmitry V. Levin <ldv@altlinux.org>
 
   Utempter library interface.
 
@@ -34,8 +34,9 @@
 
 #include "utempter.h"
 
-#define	UTEMPTER_PATH	"/usr/lib/utempter/utempter"
+#define	UTEMPTER_DEFAULT_PATHNAME	LIBEXECDIR "/utempter/utempter"
 
+static const char *utempter_pathname;
 static int saved_fd = -1;
 
 static int
@@ -96,7 +97,7 @@ execute_helper (int master_fd, const char *const argv[])
 			status = 1;
 		}
 
-		ret:
+	      ret:
 		if (!sigismember (&old_set, SIGCHLD))
 			sigprocmask (SIG_UNBLOCK, &new_set, 0);
 		return !status;
@@ -106,7 +107,9 @@ execute_helper (int master_fd, const char *const argv[])
 int
 utempter_add_record (int master_fd, const char *hostname)
 {
-	const char *const args[] = { UTEMPTER_PATH, "add", hostname, 0 };
+	const char *const args[] =
+		{ utempter_pathname ? : UTEMPTER_DEFAULT_PATHNAME, "add",
+     hostname, 0 };
 	int     status = execute_helper (master_fd, args);
 
 	if (status)
@@ -118,7 +121,8 @@ utempter_add_record (int master_fd, const char *hostname)
 int
 utempter_remove_record (int master_fd)
 {
-	const char *const args[] = { UTEMPTER_PATH, "del", 0 };
+	const char *const args[] =
+		{ utempter_pathname ? : UTEMPTER_DEFAULT_PATHNAME, "del", 0 };
 	int     status = execute_helper (master_fd, args);
 
 	if (master_fd == saved_fd)
@@ -135,3 +139,9 @@ utempter_remove_added_record (void)
 	else
 		return utempter_remove_record (saved_fd);
 }
+
+int
+utempter_set_helper (const char *pathname)
+{
+	utempter_pathname = pathname;
+}
